%global pypi_name jsonschema-specifications
%global pkg_name jsonschema_specifications

%bcond_with doc

%global common_description %{expand:
JSON support files from the JSON Schema Specifications (metaschemas,
vocabularies, etc.), packaged for runtime access from Python as a
referencing-based Schema Registry.}

Summary:        JSON Schema meta-schemas and vocabularies, exposed as a Registry
Name:           python-%{pypi_name}
Version:        2023.11.2
Release:        1%{?dist}
License:        MIT
URL:            https://github.com/python-jsonschema/jsonschema-specifications
Source0:        %{pypi_source %{pkg_name}}

BuildRequires:  python3-devel
BuildArch:      noarch

%description %{common_description}

%package -n     python3-%{pypi_name}
Summary:        JSON Schema meta-schemas and vocabularies, exposed as a Registry
%description -n python3-%{pypi_name} %{common_description}

%package -n    python3-%{pypi_name}-tests
Summary:        Tests for the JSON Schema specifications
BuildRequires:  python3dist(pytest)
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3dist(pytest)

%description -n python3-%{pypi_name}-tests
Tests for the JSON Schema specifications

%if 0%{with doc}
%package  -n    python3-%{pypi_name}-doc
Summary:        Documentation for the JSON Schema specifications
Group:          Documentation

BuildRequires:  python3dist(sphinx) python3dist(sphinxcontrib-spelling)
BuildRequires:  python3dist(sphinx-copybutton) python3dist(sphinxext-opengraph)

%description -n python3-%{pypi_name}-doc
Documentation for the JSON Schema specifications
%endif


%prep
%autosetup -n %{pkg_name}-%{version}

sed -i "/^file:.*/d" docs/requirements.in
sed -i "/^pygments-github-lexers/d" docs/requirements.in

%generate_buildrequires
%if %{with doc}
%pyproject_buildrequires -w docs/requirements.in
%else
%pyproject_buildrequires
%endif

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pkg_name}

%if %{with doc}
export PYTHONPATH="%{buildroot}/%{python3_sitelib}"
sphinx-build-3 -b html docs docs/build/html
rm -rf docs/build/html/.{doctrees,buildinfo}
%endif

%check
%pytest

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license COPYING
%doc README.rst
%exclude %{python3_sitelib}/%{pkg_name}/tests

%files -n python3-%{pypi_name}-tests
%license COPYING
%{python3_sitelib}/%{pkg_name}/tests

%if %{with doc}
%files -n python3-%{pypi_name}-doc
%doc docs/build/html
%endif

%changelog
* Wed Jun 12 2024 Shuo Wang <abushwang@tencent.com> - 2023.11.2-1
- initial build
